diff --git a/Assets/Resources/Games/marchingOrders.prefab b/Assets/Resources/Games/marchingOrders.prefab
index c2da4caa..27eb5e63 100644
--- a/Assets/Resources/Games/marchingOrders.prefab
+++ b/Assets/Resources/Games/marchingOrders.prefab
@@ -70,7 +70,7 @@ SpriteRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingLayer: 0
- m_SortingOrder: -2
+ m_SortingOrder: -3
m_Sprite: {fileID: -3480662173297360594, guid: 846441fe5edbde04f9bafc98728df9b3, type: 3}
m_Color: {r: 1, g: 1, b: 1, a: 1}
m_FlipX: 0
@@ -733,7 +733,11 @@ SpriteRenderer:
m_LightmapParameters: {fileID: 0}
m_SortingLayerID: 0
m_SortingLayer: 0
+ m_SortingOrder: -3
m_Sprite: {fileID: 2782121640304946352, guid: 846441fe5edbde04f9bafc98728df9b3, type: 3}
+ m_Color: {r: 1, g: 1, b: 1, a: 1}
+ m_FlipX: 0
+ m_FlipY: 0
m_DrawMode: 0
m_Size: {x: 1, y: 1}
m_AdaptiveModeThreshold: 0.5
@@ -939,7 +943,7 @@ GameObject:
- component: {fileID: 7150405460527854978}
- component: {fileID: 68857249694856436}
m_Layer: 0
- m_Name: bgFill
+ m_Name: bgFill1
m_TagString: Untagged
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
diff --git a/Assets/Resources/Prefabs/Games/MarchingOrders/CadetHead.prefab b/Assets/Resources/Prefabs/Games/MarchingOrders/CadetHead.prefab
new file mode 100644
index 00000000..91e2eb3c
--- /dev/null
+++ b/Assets/Resources/Prefabs/Games/MarchingOrders/CadetHead.prefab
@@ -0,0 +1,155 @@
+%YAML 1.1
+%TAG !u! tag:unity3d.com,2011:
+--- !u!1 &1254738395776798436
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 433873525218291336}
+ - component: {fileID: 8714277536144134696}
+ - component: {fileID: 3807019065815778040}
+ m_Layer: 0
+ m_Name: cadetHead
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!4 &433873525218291336
+Transform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 1254738395776798436}
+ m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children: []
+ m_Father: {fileID: 5457875550793562857}
+ m_RootOrder: 0
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+--- !u!212 &8714277536144134696
+SpriteRenderer:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 1254738395776798436}
+ m_Enabled: 1
+ m_CastShadows: 0
+ m_ReceiveShadows: 0
+ m_DynamicOccludee: 1
+ m_MotionVectors: 1
+ m_LightProbeUsage: 1
+ m_ReflectionProbeUsage: 1
+ m_RayTracingMode: 0
+ m_RayTraceProcedural: 0
+ m_RenderingLayerMask: 1
+ m_RendererPriority: 0
+ m_Materials:
+ - {fileID: 10754, guid: 0000000000000000f000000000000000, type: 0}
+ m_StaticBatchInfo:
+ firstSubMesh: 0
+ subMeshCount: 0
+ m_StaticBatchRoot: {fileID: 0}
+ m_ProbeAnchor: {fileID: 0}
+ m_LightProbeVolumeOverride: {fileID: 0}
+ m_ScaleInLightmap: 1
+ m_ReceiveGI: 1
+ m_PreserveUVs: 0
+ m_IgnoreNormalsForChartDetection: 0
+ m_ImportantGI: 0
+ m_StitchLightmapSeams: 1
+ m_SelectedEditorRenderState: 0
+ m_MinimumChartSize: 4
+ m_AutoUVMaxDistance: 0.5
+ m_AutoUVMaxAngle: 89
+ m_LightmapParameters: {fileID: 0}
+ m_SortingLayerID: 0
+ m_SortingLayer: 0
+ m_SortingOrder: 10
+ m_Sprite: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
+ m_Color: {r: 1, g: 1, b: 1, a: 1}
+ m_FlipX: 0
+ m_FlipY: 0
+ m_DrawMode: 0
+ m_Size: {x: 1, y: 1}
+ m_AdaptiveModeThreshold: 0.5
+ m_SpriteTileMode: 0
+ m_WasSpriteAssigned: 1
+ m_MaskInteraction: 0
+ m_SpriteSortPoint: 0
+--- !u!95 &3807019065815778040
+Animator:
+ serializedVersion: 3
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 1254738395776798436}
+ m_Enabled: 1
+ m_Avatar: {fileID: 0}
+ m_Controller: {fileID: 0}
+ m_CullingMode: 0
+ m_UpdateMode: 0
+ m_ApplyRootMotion: 0
+ m_LinearVelocityBlending: 0
+ m_WarningMessage:
+ m_HasTransformHierarchy: 1
+ m_AllowConstantClipSamplingOptimization: 1
+ m_KeepAnimatorControllerStateOnDisable: 0
+--- !u!1 &8861690166672522127
+GameObject:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ serializedVersion: 6
+ m_Component:
+ - component: {fileID: 5457875550793562857}
+ - component: {fileID: 1636072313462817295}
+ m_Layer: 0
+ m_Name: CadetHead
+ m_TagString: Untagged
+ m_Icon: {fileID: 0}
+ m_NavMeshLayer: 0
+ m_StaticEditorFlags: 0
+ m_IsActive: 1
+--- !u!4 &5457875550793562857
+Transform:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 8861690166672522127}
+ m_LocalRotation: {x: 0, y: 0, z: 0, w: 1}
+ m_LocalPosition: {x: 0, y: 0, z: 0}
+ m_LocalScale: {x: 1, y: 1, z: 1}
+ m_Children:
+ - {fileID: 433873525218291336}
+ m_Father: {fileID: 0}
+ m_RootOrder: 0
+ m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
+--- !u!95 &1636072313462817295
+Animator:
+ serializedVersion: 3
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_GameObject: {fileID: 8861690166672522127}
+ m_Enabled: 1
+ m_Avatar: {fileID: 0}
+ m_Controller: {fileID: 9100000, guid: b7182ddf88753b74d9b76eb8d504ae35, type: 2}
+ m_CullingMode: 0
+ m_UpdateMode: 0
+ m_ApplyRootMotion: 0
+ m_LinearVelocityBlending: 0
+ m_WarningMessage:
+ m_HasTransformHierarchy: 1
+ m_AllowConstantClipSamplingOptimization: 1
+ m_KeepAnimatorControllerStateOnDisable: 0
diff --git a/Assets/Resources/Prefabs/Games/MarchingOrders/CadetHead.prefab.meta b/Assets/Resources/Prefabs/Games/MarchingOrders/CadetHead.prefab.meta
new file mode 100644
index 00000000..3258ff6d
--- /dev/null
+++ b/Assets/Resources/Prefabs/Games/MarchingOrders/CadetHead.prefab.meta
@@ -0,0 +1,7 @@
+fileFormatVersion: 2
+guid: 1f6dd9e6033236e4099da238db2758d9
+PrefabImporter:
+ externalObjects: {}
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Assets/Resources/Prefabs/Games/MarchingOrders/Cadets.prefab b/Assets/Resources/Prefabs/Games/MarchingOrders/Cadets.prefab
index 1f9fc22a..ec0b9cc7 100644
--- a/Assets/Resources/Prefabs/Games/MarchingOrders/Cadets.prefab
+++ b/Assets/Resources/Prefabs/Games/MarchingOrders/Cadets.prefab
@@ -82,88 +82,6 @@ SpriteRenderer:
m_WasSpriteAssigned: 1
m_MaskInteraction: 0
m_SpriteSortPoint: 0
---- !u!1 &1240379293656630318
-GameObject:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- serializedVersion: 6
- m_Component:
- - component: {fileID: 5319488906539053294}
- - component: {fileID: 2325312651278163355}
- m_Layer: 0
- m_Name: cadetHead
- m_TagString: Untagged
- m_Icon: {fileID: 0}
- m_NavMeshLayer: 0
- m_StaticEditorFlags: 0
- m_IsActive: 1
---- !u!4 &5319488906539053294
-Transform:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1240379293656630318}
- m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0, y: 0.666, z: 0}
- m_LocalScale: {x: 1.04, y: 1.04, z: 1}
- m_Children: []
- m_Father: {fileID: 308962927016676861}
- m_RootOrder: 0
- m_LocalEulerAnglesHint: {x: 0, y: 0, z: 0}
---- !u!212 &2325312651278163355
-SpriteRenderer:
- m_ObjectHideFlags: 0
- m_CorrespondingSourceObject: {fileID: 0}
- m_PrefabInstance: {fileID: 0}
- m_PrefabAsset: {fileID: 0}
- m_GameObject: {fileID: 1240379293656630318}
- m_Enabled: 1
- m_CastShadows: 0
- m_ReceiveShadows: 0
- m_DynamicOccludee: 1
- m_MotionVectors: 1
- m_LightProbeUsage: 1
- m_ReflectionProbeUsage: 1
- m_RayTracingMode: 0
- m_RayTraceProcedural: 0
- m_RenderingLayerMask: 1
- m_RendererPriority: 0
- m_Materials:
- - {fileID: 10754, guid: 0000000000000000f000000000000000, type: 0}
- m_StaticBatchInfo:
- firstSubMesh: 0
- subMeshCount: 0
- m_StaticBatchRoot: {fileID: 0}
- m_ProbeAnchor: {fileID: 0}
- m_LightProbeVolumeOverride: {fileID: 0}
- m_ScaleInLightmap: 1
- m_ReceiveGI: 1
- m_PreserveUVs: 0
- m_IgnoreNormalsForChartDetection: 0
- m_ImportantGI: 0
- m_StitchLightmapSeams: 1
- m_SelectedEditorRenderState: 0
- m_MinimumChartSize: 4
- m_AutoUVMaxDistance: 0.5
- m_AutoUVMaxAngle: 89
- m_LightmapParameters: {fileID: 0}
- m_SortingLayerID: 0
- m_SortingLayer: 0
- m_SortingOrder: 10
- m_Sprite: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- m_Color: {r: 1, g: 1, b: 1, a: 1}
- m_FlipX: 0
- m_FlipY: 0
- m_DrawMode: 0
- m_Size: {x: 1, y: 1}
- m_AdaptiveModeThreshold: 0.5
- m_SpriteTileMode: 0
- m_WasSpriteAssigned: 1
- m_MaskInteraction: 0
- m_SpriteSortPoint: 0
--- !u!1 &2486501137883457502
GameObject:
m_ObjectHideFlags: 0
@@ -180,7 +98,7 @@ GameObject:
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
- m_IsActive: 1
+ m_IsActive: 0
--- !u!4 &161048534229830808
Transform:
m_ObjectHideFlags: 0
@@ -262,7 +180,7 @@ GameObject:
m_Icon: {fileID: 0}
m_NavMeshLayer: 0
m_StaticEditorFlags: 0
- m_IsActive: 1
+ m_IsActive: 0
--- !u!4 &4242949895883883619
Transform:
m_ObjectHideFlags: 0
@@ -602,7 +520,7 @@ Transform:
m_LocalPosition: {x: 0, y: 0, z: 0}
m_LocalScale: {x: 1, y: 1, z: 1}
m_Children:
- - {fileID: 5319488906539053294}
+ - {fileID: 2039381362211550255}
- {fileID: 2782604673486759644}
- {fileID: 1000208939380644342}
- {fileID: 8252745207487221176}
@@ -823,7 +741,7 @@ Transform:
m_PrefabAsset: {fileID: 0}
m_GameObject: {fileID: 9061429332552348868}
m_LocalRotation: {x: -0, y: -0, z: -0, w: 1}
- m_LocalPosition: {x: 0.166, y: -2.2257, z: 0}
+ m_LocalPosition: {x: 0.16599989, y: -2.2257, z: 0}
m_LocalScale: {x: -1.04, y: 1.04, z: 1}
m_Children: []
m_Father: {fileID: 308962927016676861}
@@ -880,3 +798,73 @@ SpriteRenderer:
m_WasSpriteAssigned: 1
m_MaskInteraction: 0
m_SpriteSortPoint: 0
+--- !u!1001 &6337429365394837190
+PrefabInstance:
+ m_ObjectHideFlags: 0
+ serializedVersion: 2
+ m_Modification:
+ m_TransformParent: {fileID: 308962927016676861}
+ m_Modifications:
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_RootOrder
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalScale.x
+ value: 1.04
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalScale.y
+ value: 1.04
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalPosition.x
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalPosition.y
+ value: 0.666
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalPosition.z
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalRotation.w
+ value: 1
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalRotation.x
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalRotation.y
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalRotation.z
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalEulerAnglesHint.x
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalEulerAnglesHint.y
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_LocalEulerAnglesHint.z
+ value: 0
+ objectReference: {fileID: 0}
+ - target: {fileID: 8861690166672522127, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ propertyPath: m_Name
+ value: CadetHead
+ objectReference: {fileID: 0}
+ m_RemovedComponents: []
+ m_SourcePrefab: {fileID: 100100000, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+--- !u!4 &2039381362211550255 stripped
+Transform:
+ m_CorrespondingSourceObject: {fileID: 5457875550793562857, guid: 1f6dd9e6033236e4099da238db2758d9, type: 3}
+ m_PrefabInstance: {fileID: 6337429365394837190}
+ m_PrefabAsset: {fileID: 0}
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Bop.anim b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Bop.anim
index cebf5dc2..fc08bdfa 100644
--- a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Bop.anim
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Bop.anim
@@ -15,58 +15,6 @@ AnimationClip:
m_CompressedRotationCurves: []
m_EulerCurves: []
m_PositionCurves:
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: {x: 0, y: 0.666, z: 0}
- inSlope: {x: 0, y: 0, z: 0}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.06666667
- value: {x: 0, y: 0.752, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.1
- value: {x: 0, y: 0.938, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: Infinity, y: Infinity, z: Infinity}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.13333334
- value: {x: 0, y: 1.061, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: Infinity, y: Infinity, z: Infinity}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.5
- value: {x: 0, y: 0.666, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- path: cadetHead
- curve:
serializedVersion: 2
m_Curve:
@@ -379,6 +327,58 @@ AnimationClip:
m_PostInfinity: 2
m_RotationOrder: 4
path: cadetArm2
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: {x: 0, y: 0.666, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.06666667
+ value: {x: 0, y: 0.752, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 2.72, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.1
+ value: {x: 0, y: 0.938, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 4.6349998, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.13333334
+ value: {x: 0, y: 1.061, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.5
+ value: {x: 0, y: 0.67444086, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ path: CadetHead
m_ScaleCurves: []
m_FloatCurves:
- curve:
@@ -513,25 +513,6 @@ AnimationClip:
path: cadetLeg1
classID: 212
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 10
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0
- outWeight: 0
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_SortingOrder
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -609,15 +590,6 @@ AnimationClip:
classID: 212
script: {fileID: 0}
m_PPtrCurves:
- - curve:
- - time: 0
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.5
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- attribute: m_Sprite
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
- time: 0
value: {fileID: 9063607464200046497, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -691,13 +663,6 @@ AnimationClip:
m_Extent: {x: 0, y: 0, z: 0}
m_ClipBindingConstant:
genericBindings:
- - serializedVersion: 2
- path: 2461089604
- attribute: 1
- script: {fileID: 0}
- typeID: 4
- customType: 0
- isPPtrCurve: 0
- serializedVersion: 2
path: 2942477482
attribute: 1
@@ -740,6 +705,13 @@ AnimationClip:
typeID: 4
customType: 0
isPPtrCurve: 0
+ - serializedVersion: 2
+ path: 272678375
+ attribute: 1
+ script: {fileID: 0}
+ typeID: 4
+ customType: 0
+ isPPtrCurve: 0
- serializedVersion: 2
path: 1992362859
attribute: 2086281974
@@ -782,13 +754,6 @@ AnimationClip:
typeID: 212
customType: 26
isPPtrCurve: 0
- - serializedVersion: 2
- path: 2461089604
- attribute: 3762991556
- script: {fileID: 0}
- typeID: 212
- customType: 26
- isPPtrCurve: 0
- serializedVersion: 2
path: 3631054582
attribute: 3762991556
@@ -817,13 +782,6 @@ AnimationClip:
typeID: 212
customType: 26
isPPtrCurve: 0
- - serializedVersion: 2
- path: 2461089604
- attribute: 0
- script: {fileID: 0}
- typeID: 212
- customType: 23
- isPPtrCurve: 1
- serializedVersion: 2
path: 2942477482
attribute: 0
@@ -867,8 +825,6 @@ AnimationClip:
customType: 23
isPPtrCurve: 1
pptrCurveMapping:
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 9063607464200046497, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 9063607464200046497, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: -7998149598989480986, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -908,171 +864,6 @@ AnimationClip:
m_HeightFromFeet: 0
m_Mirror: 0
m_EditorCurves:
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.5
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.x
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0.666
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0.752
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0.938
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 1.061
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.5
- value: 0.666
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.y
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.5
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.z
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -2195,25 +1986,6 @@ AnimationClip:
path: cadetLeg1
classID: 212
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 10
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0
- outWeight: 0
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_SortingOrder
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -2290,6 +2062,171 @@ AnimationClip:
path: cadetArm1
classID: 212
script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.5
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.x
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0.666
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0.752
+ inSlope: Infinity
+ outSlope: 2.72
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0.938
+ inSlope: Infinity
+ outSlope: 4.6349998
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 1.061
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.5
+ value: 0.67444086
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.y
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.5
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.z
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
m_EulerEditorCurves: []
m_HasGenericRootTransform: 0
m_HasMotionFloatCurves: 0
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/CadetHead.controller b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/CadetHead.controller
new file mode 100644
index 00000000..7762dafb
--- /dev/null
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/CadetHead.controller
@@ -0,0 +1,101 @@
+%YAML 1.1
+%TAG !u! tag:unity3d.com,2011:
+--- !u!1102 &-1760782239941528922
+AnimatorState:
+ serializedVersion: 6
+ m_ObjectHideFlags: 1
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_Name: FaceL
+ m_Speed: 1
+ m_CycleOffset: 0
+ m_Transitions: []
+ m_StateMachineBehaviours: []
+ m_Position: {x: 50, y: 50, z: 0}
+ m_IKOnFeet: 0
+ m_WriteDefaultValues: 1
+ m_Mirror: 0
+ m_SpeedParameterActive: 0
+ m_MirrorParameterActive: 0
+ m_CycleOffsetParameterActive: 0
+ m_TimeParameterActive: 0
+ m_Motion: {fileID: 7400000, guid: 5f347c06510ec8543befeca036553f9b, type: 2}
+ m_Tag:
+ m_SpeedParameter:
+ m_MirrorParameter:
+ m_CycleOffsetParameter:
+ m_TimeParameter:
+--- !u!91 &9100000
+AnimatorController:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_Name: CadetHead
+ serializedVersion: 5
+ m_AnimatorParameters: []
+ m_AnimatorLayers:
+ - serializedVersion: 5
+ m_Name: Base Layer
+ m_StateMachine: {fileID: 3918618367482227459}
+ m_Mask: {fileID: 0}
+ m_Motions: []
+ m_Behaviours: []
+ m_BlendingMode: 0
+ m_SyncedLayerIndex: -1
+ m_DefaultWeight: 0
+ m_IKPass: 0
+ m_SyncedLayerAffectsTiming: 0
+ m_Controller: {fileID: 9100000}
+--- !u!1107 &3918618367482227459
+AnimatorStateMachine:
+ serializedVersion: 6
+ m_ObjectHideFlags: 1
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_Name: Base Layer
+ m_ChildStates:
+ - serializedVersion: 1
+ m_State: {fileID: -1760782239941528922}
+ m_Position: {x: 200, y: 0, z: 0}
+ - serializedVersion: 1
+ m_State: {fileID: 6972647954917687390}
+ m_Position: {x: 235, y: 65, z: 0}
+ m_ChildStateMachines: []
+ m_AnyStateTransitions: []
+ m_EntryTransitions: []
+ m_StateMachineTransitions: {}
+ m_StateMachineBehaviours: []
+ m_AnyStatePosition: {x: 50, y: 20, z: 0}
+ m_EntryPosition: {x: 50, y: 120, z: 0}
+ m_ExitPosition: {x: 800, y: 120, z: 0}
+ m_ParentStateMachinePosition: {x: 800, y: 20, z: 0}
+ m_DefaultState: {fileID: -1760782239941528922}
+--- !u!1102 &6972647954917687390
+AnimatorState:
+ serializedVersion: 6
+ m_ObjectHideFlags: 1
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_Name: FaceR
+ m_Speed: 1
+ m_CycleOffset: 0
+ m_Transitions: []
+ m_StateMachineBehaviours: []
+ m_Position: {x: 50, y: 50, z: 0}
+ m_IKOnFeet: 0
+ m_WriteDefaultValues: 1
+ m_Mirror: 0
+ m_SpeedParameterActive: 0
+ m_MirrorParameterActive: 0
+ m_CycleOffsetParameterActive: 0
+ m_TimeParameterActive: 0
+ m_Motion: {fileID: 7400000, guid: ec012b597dcf54a4c8115ddfb6987cc7, type: 2}
+ m_Tag:
+ m_SpeedParameter:
+ m_MirrorParameter:
+ m_CycleOffsetParameter:
+ m_TimeParameter:
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/CadetHead.controller.meta b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/CadetHead.controller.meta
new file mode 100644
index 00000000..240d0945
--- /dev/null
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/CadetHead.controller.meta
@@ -0,0 +1,8 @@
+fileFormatVersion: 2
+guid: b7182ddf88753b74d9b76eb8d504ae35
+NativeFormatImporter:
+ externalObjects: {}
+ mainObjectFileID: 9100000
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceL.anim b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceL.anim
new file mode 100644
index 00000000..91d31d4a
--- /dev/null
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceL.anim
@@ -0,0 +1,53 @@
+%YAML 1.1
+%TAG !u! tag:unity3d.com,2011:
+--- !u!74 &7400000
+AnimationClip:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_Name: FaceL
+ serializedVersion: 6
+ m_Legacy: 0
+ m_Compressed: 0
+ m_UseHighQualityCurve: 1
+ m_RotationCurves: []
+ m_CompressedRotationCurves: []
+ m_EulerCurves: []
+ m_PositionCurves: []
+ m_ScaleCurves: []
+ m_FloatCurves: []
+ m_PPtrCurves: []
+ m_SampleRate: 60
+ m_WrapMode: 0
+ m_Bounds:
+ m_Center: {x: 0, y: 0, z: 0}
+ m_Extent: {x: 0, y: 0, z: 0}
+ m_ClipBindingConstant:
+ genericBindings: []
+ pptrCurveMapping: []
+ m_AnimationClipSettings:
+ serializedVersion: 2
+ m_AdditiveReferencePoseClip: {fileID: 0}
+ m_AdditiveReferencePoseTime: 0
+ m_StartTime: 0
+ m_StopTime: 1
+ m_OrientationOffsetY: 0
+ m_Level: 0
+ m_CycleOffset: 0
+ m_HasAdditiveReferencePose: 0
+ m_LoopTime: 0
+ m_LoopBlend: 0
+ m_LoopBlendOrientation: 0
+ m_LoopBlendPositionY: 0
+ m_LoopBlendPositionXZ: 0
+ m_KeepOriginalOrientation: 0
+ m_KeepOriginalPositionY: 1
+ m_KeepOriginalPositionXZ: 0
+ m_HeightFromFeet: 0
+ m_Mirror: 0
+ m_EditorCurves: []
+ m_EulerEditorCurves: []
+ m_HasGenericRootTransform: 0
+ m_HasMotionFloatCurves: 0
+ m_Events: []
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceL.anim.meta b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceL.anim.meta
new file mode 100644
index 00000000..a7d54304
--- /dev/null
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceL.anim.meta
@@ -0,0 +1,8 @@
+fileFormatVersion: 2
+guid: 5f347c06510ec8543befeca036553f9b
+NativeFormatImporter:
+ externalObjects: {}
+ mainObjectFileID: 7400000
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceR.anim b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceR.anim
new file mode 100644
index 00000000..bd665a74
--- /dev/null
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceR.anim
@@ -0,0 +1,53 @@
+%YAML 1.1
+%TAG !u! tag:unity3d.com,2011:
+--- !u!74 &7400000
+AnimationClip:
+ m_ObjectHideFlags: 0
+ m_CorrespondingSourceObject: {fileID: 0}
+ m_PrefabInstance: {fileID: 0}
+ m_PrefabAsset: {fileID: 0}
+ m_Name: FaceR
+ serializedVersion: 6
+ m_Legacy: 0
+ m_Compressed: 0
+ m_UseHighQualityCurve: 1
+ m_RotationCurves: []
+ m_CompressedRotationCurves: []
+ m_EulerCurves: []
+ m_PositionCurves: []
+ m_ScaleCurves: []
+ m_FloatCurves: []
+ m_PPtrCurves: []
+ m_SampleRate: 60
+ m_WrapMode: 0
+ m_Bounds:
+ m_Center: {x: 0, y: 0, z: 0}
+ m_Extent: {x: 0, y: 0, z: 0}
+ m_ClipBindingConstant:
+ genericBindings: []
+ pptrCurveMapping: []
+ m_AnimationClipSettings:
+ serializedVersion: 2
+ m_AdditiveReferencePoseClip: {fileID: 0}
+ m_AdditiveReferencePoseTime: 0
+ m_StartTime: 0
+ m_StopTime: 1
+ m_OrientationOffsetY: 0
+ m_Level: 0
+ m_CycleOffset: 0
+ m_HasAdditiveReferencePose: 0
+ m_LoopTime: 0
+ m_LoopBlend: 0
+ m_LoopBlendOrientation: 0
+ m_LoopBlendPositionY: 0
+ m_LoopBlendPositionXZ: 0
+ m_KeepOriginalOrientation: 0
+ m_KeepOriginalPositionY: 1
+ m_KeepOriginalPositionXZ: 0
+ m_HeightFromFeet: 0
+ m_Mirror: 0
+ m_EditorCurves: []
+ m_EulerEditorCurves: []
+ m_HasGenericRootTransform: 0
+ m_HasMotionFloatCurves: 0
+ m_Events: []
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceR.anim.meta b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceR.anim.meta
new file mode 100644
index 00000000..d4c5749d
--- /dev/null
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/FaceR.anim.meta
@@ -0,0 +1,8 @@
+fileFormatVersion: 2
+guid: ec012b597dcf54a4c8115ddfb6987cc7
+NativeFormatImporter:
+ externalObjects: {}
+ mainObjectFileID: 7400000
+ userData:
+ assetBundleName:
+ assetBundleVariant:
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Halt.anim b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Halt.anim
index c54eb01b..446f570a 100644
--- a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Halt.anim
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Halt.anim
@@ -55,7 +55,7 @@ AnimationClip:
inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: {x: -0.406, y: -0.915, z: 0}
inSlope: {x: Infinity, y: Infinity, z: Infinity}
outSlope: {x: 0, y: 0, z: 0}
@@ -107,7 +107,7 @@ AnimationClip:
inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: {x: 0.406, y: -0.915, z: 0}
inSlope: {x: Infinity, y: Infinity, z: Infinity}
outSlope: {x: 0, y: 0, z: 0}
@@ -119,58 +119,6 @@ AnimationClip:
m_PostInfinity: 2
m_RotationOrder: 4
path: cadetArm2
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: {x: 0, y: 1.061, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: Infinity, y: Infinity, z: Infinity}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.06666667
- value: {x: 0, y: 0.938, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: Infinity, y: Infinity, z: Infinity}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.1
- value: {x: 0, y: 0.752, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.13333334
- value: {x: 0, y: 0.666, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.48333332
- value: {x: 0, y: 0.666, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- path: cadetHead
- curve:
serializedVersion: 2
m_Curve:
@@ -211,7 +159,7 @@ AnimationClip:
inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: {x: -0.166, y: -2.2257, z: 0}
inSlope: {x: Infinity, y: Infinity, z: Infinity}
outSlope: {x: 0, y: 0, z: 0}
@@ -263,7 +211,7 @@ AnimationClip:
inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: {x: 0.166, y: -2.2257, z: 0}
inSlope: {x: Infinity, y: Infinity, z: Infinity}
outSlope: {x: 0, y: 0, z: 0}
@@ -315,7 +263,7 @@ AnimationClip:
inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: {x: 0.018, y: -0.041999996, z: 0}
inSlope: {x: Infinity, y: Infinity, z: Infinity}
outSlope: {x: 0, y: 0, z: 0}
@@ -360,14 +308,14 @@ AnimationClip:
- serializedVersion: 3
time: 0.13333334
value: {x: 0, y: -0.77, z: 0}
- inSlope: {x: 0, y: 0, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
outSlope: {x: 0, y: 0, z: 0}
tangentMode: 0
weightedMode: 0
inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: {x: 0, y: -0.77, z: 0}
inSlope: {x: Infinity, y: Infinity, z: Infinity}
outSlope: {x: 0, y: 0, z: 0}
@@ -379,6 +327,58 @@ AnimationClip:
m_PostInfinity: 2
m_RotationOrder: 4
path: cadetTorso
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: {x: 0, y: 1.061, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.06666667
+ value: {x: 0, y: 0.938, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.1
+ value: {x: 0, y: 0.752, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.13333334
+ value: {x: 0, y: 0.666, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.5
+ value: {x: 0, y: 0.666, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ path: CadetHead
m_ScaleCurves: []
m_FloatCurves:
- curve:
@@ -513,25 +513,6 @@ AnimationClip:
path: cadetHand2
classID: 212
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 10
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0
- outWeight: 0
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_SortingOrder
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -612,7 +593,7 @@ AnimationClip:
- curve:
- time: 0
value: {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.48333332
+ - time: 0.5
value: {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
attribute: m_Sprite
path: cadetArm1
@@ -621,21 +602,12 @@ AnimationClip:
- curve:
- time: 0
value: {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.48333332
+ - time: 0.5
value: {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
attribute: m_Sprite
path: cadetArm2
classID: 212
script: {fileID: 0}
- - curve:
- - time: 0
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.48333332
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- attribute: m_Sprite
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
- time: 0
value: {fileID: -1301704698906724469, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -645,7 +617,7 @@ AnimationClip:
value: {fileID: 2172702904053088867, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- time: 0.13333334
value: {fileID: 1876675414622521761, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.48333332
+ - time: 0.5
value: {fileID: 1876675414622521761, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
attribute: m_Sprite
path: cadetLeg1
@@ -660,7 +632,7 @@ AnimationClip:
value: {fileID: 2172702904053088867, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- time: 0.13333334
value: {fileID: 1876675414622521761, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.48333332
+ - time: 0.5
value: {fileID: 1876675414622521761, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
attribute: m_Sprite
path: cadetLeg2
@@ -669,7 +641,7 @@ AnimationClip:
- curve:
- time: 0
value: {fileID: -7998149598989480986, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.48333332
+ - time: 0.5
value: {fileID: -7998149598989480986, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
attribute: m_Sprite
path: cadetNeck
@@ -678,7 +650,7 @@ AnimationClip:
- curve:
- time: 0
value: {fileID: 9063607464200046497, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.48333332
+ - time: 0.5
value: {fileID: 9063607464200046497, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
attribute: m_Sprite
path: cadetTorso
@@ -705,13 +677,6 @@ AnimationClip:
typeID: 4
customType: 0
isPPtrCurve: 0
- - serializedVersion: 2
- path: 2461089604
- attribute: 1
- script: {fileID: 0}
- typeID: 4
- customType: 0
- isPPtrCurve: 0
- serializedVersion: 2
path: 1351133934
attribute: 1
@@ -740,6 +705,13 @@ AnimationClip:
typeID: 4
customType: 0
isPPtrCurve: 0
+ - serializedVersion: 2
+ path: 272678375
+ attribute: 1
+ script: {fileID: 0}
+ typeID: 4
+ customType: 0
+ isPPtrCurve: 0
- serializedVersion: 2
path: 1992362859
attribute: 2086281974
@@ -782,13 +754,6 @@ AnimationClip:
typeID: 212
customType: 26
isPPtrCurve: 0
- - serializedVersion: 2
- path: 2461089604
- attribute: 3762991556
- script: {fileID: 0}
- typeID: 212
- customType: 26
- isPPtrCurve: 0
- serializedVersion: 2
path: 1351133934
attribute: 3762991556
@@ -831,13 +796,6 @@ AnimationClip:
typeID: 212
customType: 23
isPPtrCurve: 1
- - serializedVersion: 2
- path: 2461089604
- attribute: 0
- script: {fileID: 0}
- typeID: 212
- customType: 23
- isPPtrCurve: 1
- serializedVersion: 2
path: 1351133934
attribute: 0
@@ -871,8 +829,6 @@ AnimationClip:
- {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: -1301704698906724469, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 2168451732842096726, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 2172702904053088867, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -892,12 +848,12 @@ AnimationClip:
m_AdditiveReferencePoseClip: {fileID: 0}
m_AdditiveReferencePoseTime: 0
m_StartTime: 0
- m_StopTime: 0.5
+ m_StopTime: 0.51666665
m_OrientationOffsetY: 0
m_Level: 0
m_CycleOffset: 0
m_HasAdditiveReferencePose: 0
- m_LoopTime: 1
+ m_LoopTime: 0
m_LoopBlend: 0
m_LoopBlendOrientation: 0
m_LoopBlendPositionY: 0
@@ -948,7 +904,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -0.406
inSlope: Infinity
outSlope: 0
@@ -1003,7 +959,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -0.915
inSlope: Infinity
outSlope: 0
@@ -1058,7 +1014,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0
inSlope: Infinity
outSlope: 0
@@ -1113,7 +1069,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0.406
inSlope: Infinity
outSlope: 0
@@ -1168,7 +1124,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -0.915
inSlope: Infinity
outSlope: 0
@@ -1223,7 +1179,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0
inSlope: Infinity
outSlope: 0
@@ -1238,171 +1194,6 @@ AnimationClip:
path: cadetArm2
classID: 4
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.48333332
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.x
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 1.061
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0.938
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0.752
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0.666
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.48333332
- value: 0.666
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.y
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.48333332
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.z
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -1443,7 +1234,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -0.166
inSlope: Infinity
outSlope: 0
@@ -1498,7 +1289,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -2.2257
inSlope: Infinity
outSlope: 0
@@ -1553,7 +1344,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0
inSlope: Infinity
outSlope: 0
@@ -1608,7 +1399,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0.166
inSlope: Infinity
outSlope: 0
@@ -1663,7 +1454,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -2.2257
inSlope: Infinity
outSlope: 0
@@ -1718,7 +1509,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0
inSlope: Infinity
outSlope: 0
@@ -1773,7 +1564,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0.018
inSlope: Infinity
outSlope: 0
@@ -1828,7 +1619,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -0.041999996
inSlope: Infinity
outSlope: 0
@@ -1883,7 +1674,7 @@ AnimationClip:
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0
inSlope: Infinity
outSlope: 0
@@ -1931,14 +1722,14 @@ AnimationClip:
- serializedVersion: 3
time: 0.13333334
value: 0
- inSlope: 0
+ inSlope: Infinity
outSlope: 0
- tangentMode: 136
+ tangentMode: 7
weightedMode: 0
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0
inSlope: Infinity
outSlope: 0
@@ -1986,14 +1777,14 @@ AnimationClip:
- serializedVersion: 3
time: 0.13333334
value: -0.77
- inSlope: 0
+ inSlope: Infinity
outSlope: 0
- tangentMode: 136
+ tangentMode: 7
weightedMode: 0
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: -0.77
inSlope: Infinity
outSlope: 0
@@ -2041,14 +1832,14 @@ AnimationClip:
- serializedVersion: 3
time: 0.13333334
value: 0
- inSlope: 0
+ inSlope: Infinity
outSlope: 0
- tangentMode: 136
+ tangentMode: 7
weightedMode: 0
inWeight: 0.33333334
outWeight: 0.33333334
- serializedVersion: 3
- time: 0.48333332
+ time: 0.5
value: 0
inSlope: Infinity
outSlope: 0
@@ -2195,25 +1986,6 @@ AnimationClip:
path: cadetHand2
classID: 212
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 10
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0
- outWeight: 0
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_SortingOrder
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -2290,6 +2062,171 @@ AnimationClip:
path: cadetTorso
classID: 212
script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.5
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.x
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 1.061
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0.938
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0.752
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0.666
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.5
+ value: 0.666
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.y
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.5
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.z
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
m_EulerEditorCurves: []
m_HasGenericRootTransform: 0
m_HasMotionFloatCurves: 0
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Idle.anim b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Idle.anim
index 19f3f7a4..6230d737 100644
--- a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Idle.anim
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/Idle.anim
@@ -15,31 +15,6 @@ AnimationClip:
m_CompressedRotationCurves: []
m_EulerCurves: []
m_PositionCurves:
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: {x: 0, y: 0.666, z: 0}
- inSlope: {x: 0, y: 0, z: 0}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.016666668
- value: {x: 0, y: 0.666, z: 0}
- inSlope: {x: 0, y: 0, z: 0}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- path: cadetHead
- curve:
serializedVersion: 2
m_Curve:
@@ -190,6 +165,31 @@ AnimationClip:
m_PostInfinity: 2
m_RotationOrder: 4
path: cadetArm2
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: {x: 0, y: 0.666, z: 0}
+ inSlope: {x: 0, y: 0, z: 0}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.016666668
+ value: {x: 0, y: 0.666, z: 0}
+ inSlope: {x: 0, y: 0, z: 0}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ path: CadetHead
m_ScaleCurves: []
m_FloatCurves:
- curve:
@@ -248,25 +248,6 @@ AnimationClip:
path: cadetHand2
classID: 1
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 10
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0
- outWeight: 0
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_SortingOrder
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -420,13 +401,6 @@ AnimationClip:
classID: 212
script: {fileID: 0}
m_PPtrCurves:
- - curve:
- - time: 0
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- attribute: m_Sprite
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
- time: 0
value: {fileID: 9063607464200046497, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -490,13 +464,6 @@ AnimationClip:
typeID: 1
customType: 0
isPPtrCurve: 0
- - serializedVersion: 2
- path: 2461089604
- attribute: 3762991556
- script: {fileID: 0}
- typeID: 212
- customType: 26
- isPPtrCurve: 0
- serializedVersion: 2
path: 1097084748
attribute: 3762991556
@@ -553,13 +520,6 @@ AnimationClip:
typeID: 212
customType: 26
isPPtrCurve: 0
- - serializedVersion: 2
- path: 2461089604
- attribute: 0
- script: {fileID: 0}
- typeID: 212
- customType: 23
- isPPtrCurve: 1
- serializedVersion: 2
path: 2942477482
attribute: 0
@@ -602,13 +562,6 @@ AnimationClip:
typeID: 212
customType: 23
isPPtrCurve: 1
- - serializedVersion: 2
- path: 2461089604
- attribute: 1
- script: {fileID: 0}
- typeID: 4
- customType: 0
- isPPtrCurve: 0
- serializedVersion: 2
path: 2942477482
attribute: 1
@@ -651,8 +604,14 @@ AnimationClip:
typeID: 4
customType: 0
isPPtrCurve: 0
+ - serializedVersion: 2
+ path: 272678375
+ attribute: 1
+ script: {fileID: 0}
+ typeID: 4
+ customType: 0
+ isPPtrCurve: 0
pptrCurveMapping:
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 9063607464200046497, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: -7998149598989480986, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 1876675414622521761, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -680,90 +639,6 @@ AnimationClip:
m_HeightFromFeet: 0
m_Mirror: 0
m_EditorCurves:
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.016666668
- value: 0
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.x
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0.666
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.016666668
- value: 0.666
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.y
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.016666668
- value: 0
- inSlope: 0
- outSlope: 0
- tangentMode: 136
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.z
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -1324,25 +1199,6 @@ AnimationClip:
path: cadetHand2
classID: 1
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 10
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0
- outWeight: 0
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_SortingOrder
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -1495,6 +1351,90 @@ AnimationClip:
path: cadetTorso
classID: 212
script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: 0
+ outSlope: 0
+ tangentMode: 136
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.016666668
+ value: 0
+ inSlope: 0
+ outSlope: 0
+ tangentMode: 136
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.x
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0.666
+ inSlope: 0
+ outSlope: 0
+ tangentMode: 136
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.016666668
+ value: 0.666
+ inSlope: 0
+ outSlope: 0
+ tangentMode: 136
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.y
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: 0
+ outSlope: 0
+ tangentMode: 136
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.016666668
+ value: 0
+ inSlope: 0
+ outSlope: 0
+ tangentMode: 136
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.z
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
m_EulerEditorCurves: []
m_HasGenericRootTransform: 0
m_HasMotionFloatCurves: 0
diff --git a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/MarchL.anim b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/MarchL.anim
index 0a8c2f1b..1a92facf 100644
--- a/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/MarchL.anim
+++ b/Assets/Resources/Sprites/Games/MarchingOrders/Animations/Cadets/MarchL.anim
@@ -309,58 +309,6 @@ AnimationClip:
m_PostInfinity: 2
m_RotationOrder: 4
path: cadetArm2
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: {x: 0, y: 0.666, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.033333335
- value: {x: 0, y: 0.605, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: -1.2900003, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.06666667
- value: {x: 0, y: 0.58, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: 0, y: 0, z: 0}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.1
- value: {x: 0, y: 0.56, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: Infinity, y: Infinity, z: Infinity}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- - serializedVersion: 3
- time: 0.13333334
- value: {x: 0, y: 0.52, z: 0}
- inSlope: {x: Infinity, y: Infinity, z: Infinity}
- outSlope: {x: Infinity, y: Infinity, z: Infinity}
- tangentMode: 0
- weightedMode: 0
- inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- path: cadetHead
- curve:
serializedVersion: 2
m_Curve:
@@ -619,6 +567,58 @@ AnimationClip:
m_PostInfinity: 2
m_RotationOrder: 4
path: cadetHand1
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: {x: 0, y: 0.666, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.033333335
+ value: {x: 0, y: 0.605, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.06666667
+ value: {x: 0, y: 0.58, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.1
+ value: {x: 0, y: 0.56, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ - serializedVersion: 3
+ time: 0.13333334
+ value: {x: 0, y: 0.52, z: 0}
+ inSlope: {x: Infinity, y: Infinity, z: Infinity}
+ outSlope: {x: 0, y: 0, z: 0}
+ tangentMode: 0
+ weightedMode: 0
+ inWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ outWeight: {x: 0.33333334, y: 0.33333334, z: 0.33333334}
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ path: CadetHead
m_ScaleCurves:
- curve:
serializedVersion: 2
@@ -836,17 +836,6 @@ AnimationClip:
path: cadetArm2
classID: 212
script: {fileID: 0}
- - curve:
- - time: 0
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.033333335
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - time: 0.06666667
- value: {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- attribute: m_Sprite
- path: cadetHead
- classID: 212
- script: {fileID: 0}
- curve:
- time: 0
value: {fileID: 1876675414622521761, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -916,13 +905,6 @@ AnimationClip:
typeID: 4
customType: 0
isPPtrCurve: 0
- - serializedVersion: 2
- path: 2461089604
- attribute: 1
- script: {fileID: 0}
- typeID: 4
- customType: 0
- isPPtrCurve: 0
- serializedVersion: 2
path: 1351133934
attribute: 1
@@ -965,6 +947,13 @@ AnimationClip:
typeID: 4
customType: 0
isPPtrCurve: 0
+ - serializedVersion: 2
+ path: 272678375
+ attribute: 1
+ script: {fileID: 0}
+ typeID: 4
+ customType: 0
+ isPPtrCurve: 0
- serializedVersion: 2
path: 1097084748
attribute: 4
@@ -1049,13 +1038,6 @@ AnimationClip:
typeID: 212
customType: 23
isPPtrCurve: 1
- - serializedVersion: 2
- path: 2461089604
- attribute: 0
- script: {fileID: 0}
- typeID: 212
- customType: 23
- isPPtrCurve: 1
- serializedVersion: 2
path: 1351133934
attribute: 0
@@ -1091,9 +1073,6 @@ AnimationClip:
- {fileID: 6271359101650170431, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: -291518656075743311, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 1865138272167363049, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- - {fileID: -611560658681698378, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 1876675414622521761, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 7542399567275105427, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
- {fileID: 6725708096483345472, guid: 07a712fc3a8592248b24d4108837306c, type: 3}
@@ -1459,171 +1438,6 @@ AnimationClip:
path: cadetArm2
classID: 4
script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.033333335
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.x
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0.666
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.033333335
- value: 0.605
- inSlope: Infinity
- outSlope: -1.2900003
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0.58
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0.56
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0.52
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.y
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- - curve:
- serializedVersion: 2
- m_Curve:
- - serializedVersion: 3
- time: 0
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.033333335
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.06666667
- value: 0
- inSlope: Infinity
- outSlope: 0
- tangentMode: 7
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.1
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- - serializedVersion: 3
- time: 0.13333334
- value: 0
- inSlope: Infinity
- outSlope: Infinity
- tangentMode: 103
- weightedMode: 0
- inWeight: 0.33333334
- outWeight: 0.33333334
- m_PreInfinity: 2
- m_PostInfinity: 2
- m_RotationOrder: 4
- attribute: m_LocalPosition.z
- path: cadetHead
- classID: 4
- script: {fileID: 0}
- curve:
serializedVersion: 2
m_Curve:
@@ -3327,6 +3141,171 @@ AnimationClip:
path: cadetLeg1
classID: 212
script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.033333335
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.x
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0.666
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.033333335
+ value: 0.605
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0.58
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0.56
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0.52
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.y
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
+ - curve:
+ serializedVersion: 2
+ m_Curve:
+ - serializedVersion: 3
+ time: 0
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.033333335
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.06666667
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.1
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ - serializedVersion: 3
+ time: 0.13333334
+ value: 0
+ inSlope: Infinity
+ outSlope: 0
+ tangentMode: 7
+ weightedMode: 0
+ inWeight: 0.33333334
+ outWeight: 0.33333334
+ m_PreInfinity: 2
+ m_PostInfinity: 2
+ m_RotationOrder: 4
+ attribute: m_LocalPosition.z
+ path: CadetHead
+ classID: 4
+ script: {fileID: 0}
m_EulerEditorCurves:
- curve:
serializedVersion: 2
diff --git a/Assets/Scripts/Games/SpaceSoccer/SpaceSoccer.cs b/Assets/Scripts/Games/SpaceSoccer/SpaceSoccer.cs
index 48101ffc..1ce348b3 100644
--- a/Assets/Scripts/Games/SpaceSoccer/SpaceSoccer.cs
+++ b/Assets/Scripts/Games/SpaceSoccer/SpaceSoccer.cs
@@ -34,7 +34,8 @@ namespace HeavenStudio.Games.Loaders
new GameAction("keep-up", "")
{
defaultLength = 4f,
- resizable = true
+ resizable = true,
+ hidden = true
},
});
}
diff --git a/Assets/Scripts/Games/MarchingOrders/MarchingOrders.cs b/Assets/Scripts/Games/MarchingOrders/MarchingOrders.cs
index 41b38189..4fb9fd42 100644
--- a/Assets/Scripts/Games/MarchingOrders/MarchingOrders.cs
+++ b/Assets/Scripts/Games/MarchingOrders/MarchingOrders.cs
@@ -1,14 +1,15 @@
//notes:
// BEFORE NEW PROPS
-//1. minenice will also use this to test out randomly named parameters so coding has to rest until the new props update [DONE]
-//2. see fan club for separate prefabs (cadets) [DONE]
-//3. temporarily take sounds from rhre, wait until someone records the full code, including misses, or record it myself (unlikely) [IN PROGRESS]
+// - minenice will also use this to test out randomly named parameters so coding has to rest until the new props update [DONE]
+// - see fan club for separate prefabs (cadets) [DONE]
+// - temporarily take sounds from rhre, wait until someone records the full code, including misses, or record it myself (unlikely) [IN PROGRESS]
// AFTER NEW PROPS
//4. see space soccer, mr upbeat, tunnel for keep-the-beat codes
//5. figure how to do custom bg changes when the upscaled textures are finished (see karate man, launch party once it releases)
//6. will use a textbox without going through the visual options but i wonder how..?? (see first contact if ever textboxes are implemented in said minigame)
// AFTER FEATURE COMPLETION
-//7. delete all notes once the minigame is considered feature-complete
+// - delete all notes once the minigame is considered feature-complete
using HeavenStudio.Util;
using System;
@@ -30,7 +31,12 @@ namespace HeavenStudio.Games.Loaders
resizable = true
},
- //new GameAction("marching", delegate { MarchingOrders.instance.CadetsMarch(eventCaller.currentEntity.beat); }, 4f, true),
+ new GameAction("marching", "Cadets March")
+ {
+ function = delegate { var e = eventCaller.currentEntity; MarchingOrders.instance.CadetsMarch(e.beat, e.length); },
+ defaultLength = 4f,
+ resizable = true
+ },
new GameAction("attention", "Attention...")
{
@@ -49,7 +55,8 @@ namespace HeavenStudio.Games.Loaders
new GameAction("halt", "Halt!")
{
function = delegate { var e = eventCaller.currentEntity; MarchingOrders.instance.SargeHalt(e.beat); },
- defaultLength = 2f
+ defaultLength = 2f,
+ inactiveFunction = delegate { var e = eventCaller.currentEntity; MarchingOrders.HaltSound(e.beat);}
},
//new GameAction("face turn", delegate {}, 4f, false, parameters: new List()
@@ -79,6 +86,7 @@ namespace HeavenStudio.Games
public GameEvent bop = new GameEvent();
public GameEvent noBop = new GameEvent();
+ public GameEvent marching = new GameEvent();
public static MarchingOrders instance;
@@ -115,6 +123,17 @@ namespace HeavenStudio.Games
}
}
+ if (cond.ReportBeat(ref marching.lastReportedBeat, bop.startBeat % 1))
+ {
+ if (cond.songPositionInBeats >= marching.startBeat && cond.songPositionInBeats < marching.startBeat + marching.length)
+ {
+ Jukebox.PlayOneShotGame("marchingOrders/step1");
+ Cadet1.DoScaledAnimationAsync("MarchL", 0.5f);
+ Cadet2.DoScaledAnimationAsync("MarchL", 0.5f);
+ Cadet3.DoScaledAnimationAsync("MarchL", 0.5f);
+ }
+ }
+
if (PlayerInput.Pressed() && !IsExpectingInputNow())
{
Jukebox.PlayOneShot("miss");
@@ -128,9 +147,10 @@ namespace HeavenStudio.Games
bop.startBeat = beat;
}
- public void CadetsMarch(float beat)
+ public void CadetsMarch(float beat, float length)
{
-
+ marching.length = length;
+ marching.startBeat = beat;
}
public void SargeAttention(float beat)
@@ -169,11 +189,15 @@ namespace HeavenStudio.Games
MultiSound.Play(new MultiSound.Sound[] {
new MultiSound.Sound("marchingOrders/halt1", beat),
new MultiSound.Sound("marchingOrders/halt2", beat + 1f),
+ new MultiSound.Sound("marchingOrders/step1", beat + 1f),
}, forcePlay:true);
BeatAction.New(Player, new List()
{
new BeatAction.Action(beat, delegate { Sarge.DoScaledAnimationAsync("Talk", 0.5f);}),
+ new BeatAction.Action(beat + 1f, delegate { Cadet1.DoScaledAnimationAsync("Halt", 0.5f);}),
+ new BeatAction.Action(beat + 1f, delegate { Cadet2.DoScaledAnimationAsync("Halt", 0.5f);}),
+ new BeatAction.Action(beat + 1f, delegate { Cadet3.DoScaledAnimationAsync("Halt", 0.5f);}),
});
}
@@ -192,6 +216,14 @@ namespace HeavenStudio.Games
new MultiSound.Sound("marchingOrders/march1", beat),
new MultiSound.Sound("marchingOrders/march2", beat + 1f),
}, forcePlay:true);
+ }
+
+ public static void HaltSound(float beat)
+ {
+ MultiSound.Play(new MultiSound.Sound[] {
+ new MultiSound.Sound("marchingOrders/halt1", beat),
+ new MultiSound.Sound("marchingOrders/halt2", beat + 1f),
+ }, forcePlay:true);
}
}
}
@@ -1,14 +1,15 @@
// AFTER NEW PROPS
-//4. see space soccer, mr upbeat, tunnel for keep-the-beat codes
-//5. figure how to do custom bg changes when the upscaled textures are finished (see karate man, launch party once it releases)
-//6. will use a textbox without going through the visual options but i wonder how..?? (see first contact if ever textboxes are implemented in said minigame)
+// - testmod marching orders using speed
+// - see space soccer, mr upbeat, tunnel for keep-the-beat codes
+// - figure how to do custom bg changes when the upscaled textures are finished (see karate man, launch party once it releases)
+// - will use a textbox without going through the visual options but i wonder how..?? (see first contact if ever textboxes are implemented in said minigame)
// AFTER FEATURE COMPLETION